<?php
/*
Plugin Name: is_child
Plugin URI: http://www.christianschenk.org/blog/wordpress-is_child-function/
Description: Allows you to check whether the current page is a child of another page.
Version: 1.1
Author: Christian Schenk
Author URI: http://www.christianschenk.org/
*/

#
# is_child
# Copyright (C) 2009-2011 Christian Schenk
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

if (!function_exists('is_child')) {
	/**
	 * Tests whether the current post is a child of the given parent post. By
	 * default it will test parent pages up to the root but this can be
	 * disabled by setting depthTest to false.
	 */
	function is_child($parent, $depthTest = true) {
		if (empty($parent)) return false;

		$id = $parent;
		if (!is_numeric($id))
			$id = isc_get_parent_by_name($id);
		if (empty($id)) return false;

		global $post;
		if ($post->post_parent == $id)
			return true;

		if ($depthTest) {
			$parents = isc_get_all_parents($post->post_parent);
			return in_array($id, $parents);
		}

		return false;
	}

	/**
	 * Returns the parent page for a given page.
	 */
	function isc_get_parent($id) {
		global $wpdb;
		return $wpdb->get_var('SELECT post_parent FROM '.$wpdb->posts.' WHERE ID = "'.$id.'"');
	}

	/**
	 * In case the user supplied a post/page by name we'll retrieve the ID
	 * using this function.
	 */
	function isc_get_parent_by_name($name) {
		global $wpdb;
		return $wpdb->get_var('SELECT ID FROM '.$wpdb->posts.' WHERE post_name = "'.$name.'"');
	}

	/**
	 * Returns all parents up to the root node for the given page.
	 */
	function isc_get_all_parents($id) {
		$parents = array();
		$curId = $id;
		while ($curId != 0) {
			$curId = isc_get_parent($curId);
			if ($curId != 0)
				$parents[] = $curId;
		}
		return $parents;
	}
}

# File Ends Here